@@ -17,10 +17,10 @@ writeGPS <- function (xy, o = "garmin", F = "usb:", proj = '+proj=nzmg')  {
     }
     else {
         ## express as lat long
-        if (!require (rgdal))
-            stop ("package 'rgdal' required for writeGPS")
+        ## if (!require (rgdal))
+        ##    stop ("package 'rgdal' required for writeGPS")
         xy <- as.matrix(xy)  ## required by rgdal, not proj4
-        latlon <- project (xy, inv = TRUE, proj)
+        latlon <- rgdal::project (xy, inv = TRUE, proj)
     }
 
     latlon <- data.frame(latlon)[,c(2,1)] ## need lat first
